@@ -2,14 +2,14 @@
 **  Copyright (c) 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-arf.h,v 1.1 2008/05/22 06:28:08 msk Exp $
+**  $Id: dkim-arf.h,v 1.2 2008/07/10 21:51:11 msk Exp $
 */
 
 #ifndef _DKIM_ARF_H_
 #define _DKIM_ARF_H_
 
 #ifndef lint
-static char dkim_arf_h_id[] = "@(#)$Id: dkim-arf.h,v 1.1 2008/05/22 06:28:08 msk Exp $";
+static char dkim_arf_h_id[] = "@(#)$Id: dkim-arf.h,v 1.2 2008/07/10 21:51:11 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -45,9 +45,9 @@ static char dkim_arf_h_id[] = "@(#)$Id: dkim-arf.h,v 1.1 2008/05/22 06:28:08 msk
 #define	ARF_OPTIONS_DKIM_VERIFY	"v"
 #define	ARF_OPTIONS_DKIM_EXPIRED "x"
 
-#define	ARF_OPTIONS_ASP_ALL	"all"
-#define	ARF_OPTIONS_ASP_SIGNED	"s"
-#define	ARF_OPTIONS_ASP_UNSIGNED "u"
+#define	ARF_OPTIONS_ADSP_ALL	"all"
+#define	ARF_OPTIONS_ADSP_SIGNED	"s"
+#define	ARF_OPTIONS_ADSP_UNSIGNED "u"
 
 /* prototypes */
 extern char *arf_dkim_failure_string __P((int));
