@@ -2,14 +2,14 @@
 **  Copyright (c) 2006-2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-config.h,v 1.65.2.1 2008/08/19 19:46:13 msk Exp $
+**  $Id: dkim-config.h,v 1.74 2008/12/24 20:41:48 msk Exp $
 */
 
 #ifndef _DKIM_CONFIG_H_
 #define _DKIM_CONFIG_H_
 
 #ifndef lint
-static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.65.2.1 2008/08/19 19:46:13 msk Exp $";
+static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.74 2008/12/24 20:41:48 msk Exp $";
 #endif /* !lint */
 
 struct configdef dkimf_config[] =
@@ -19,17 +19,26 @@ struct configdef dkimf_config[] =
 	{ "AllowSHA1Only",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AlwaysAddARHeader",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AlwaysSignHeaders",		CONFIG_TYPE_STRING,	FALSE },
+	{ "AuthservID",			CONFIG_TYPE_STRING,	FALSE },
 	{ "AuthservIDWithJobID",	CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AutoRestart",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AutoRestartCount",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "AutoRestartRate",		CONFIG_TYPE_STRING,	FALSE },
 	{ "Background",			CONFIG_TYPE_BOOLEAN,	FALSE },
+	{ "BaseDirectory",		CONFIG_TYPE_STRING,	FALSE },
 	{ "BodyLengths",		CONFIG_TYPE_BOOLEAN,	FALSE },
 #if _FFR_BODYLENGTH_DB
 	{ "BodyLengthDBFile",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_BODYLENGTH_DB */
+#ifdef USE_UNBOUND
+	{ "BogusKey",			CONFIG_TYPE_STRING,	FALSE },
+	{ "BogusPolicy",		CONFIG_TYPE_STRING,	FALSE },
+#endif /* USE_UNBOUND*/
 	{ "Canonicalization",		CONFIG_TYPE_STRING,	FALSE },
 	{ "ClockDrift",			CONFIG_TYPE_INTEGER,	FALSE },
+#ifdef _FFR_COMMAIZE
+	{ "Commaize",			CONFIG_TYPE_BOOLEAN,	FALSE },
+#endif /* _FFR_COMMAIZE */
 	{ "Diagnostics",		CONFIG_TYPE_BOOLEAN,	FALSE },
 #ifdef _FFR_ZTAGS
 	{ "DiagnosticDirectory",	CONFIG_TYPE_STRING,	FALSE },
@@ -37,10 +46,16 @@ struct configdef dkimf_config[] =
 	{ "DNSTimeout",			CONFIG_TYPE_INTEGER,	FALSE },
 	{ "Domain",			CONFIG_TYPE_STRING,	FALSE },
 	{ "DontSignMailTo",		CONFIG_TYPE_STRING,	FALSE },
+	{ "EnableCoredumps",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "ExternalIgnoreList",		CONFIG_TYPE_STRING,	FALSE },
 	{ "FixCRLF",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "Include",			CONFIG_TYPE_INCLUDE,	FALSE },
+#ifdef USE_UNBOUND
+	{ "InsecureKey",		CONFIG_TYPE_STRING,	FALSE },
+	{ "InsecurePolicy",		CONFIG_TYPE_STRING,	FALSE },
+#endif /* USE_UNBOUND */
 	{ "InternalHosts",		CONFIG_TYPE_STRING,	FALSE },
+	{ "KeepTemporaryFiles",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "KeyFile",			CONFIG_TYPE_STRING,	FALSE },
 	{ "KeyList",			CONFIG_TYPE_STRING,	FALSE },
 	{ "LocalADSP",			CONFIG_TYPE_STRING,	FALSE },
@@ -50,6 +65,9 @@ struct configdef dkimf_config[] =
 	{ "MacroList",			CONFIG_TYPE_STRING,	FALSE },
 	{ "MilterDebug",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "Minimum",			CONFIG_TYPE_STRING,	FALSE },
+#ifdef _FFR_MULTIPLE_SIGNATURES
+	{ "MultipleSignatures",		CONFIG_TYPE_BOOLEAN,	FALSE },
+#endif /* _FFR_MULTIPLE_SIGNATURES */
 	{ "Mode",			CONFIG_TYPE_STRING,	FALSE },
 	{ "MTA",			CONFIG_TYPE_STRING,	FALSE },
 	{ "MustBeSigned",		CONFIG_TYPE_STRING,	FALSE },
@@ -66,7 +84,6 @@ struct configdef dkimf_config[] =
 #ifdef POPAUTH
 	{ "POPDBFile",			CONFIG_TYPE_STRING,	FALSE },
 #endif /* POPAUTH */
-	{ "TestPublicKeys",		CONFIG_TYPE_STRING,	FALSE },
 	{ "Quarantine",			CONFIG_TYPE_BOOLEAN,	FALSE },
 #ifdef QUERY_CACHE
 	{ "QueryCache",			CONFIG_TYPE_BOOLEAN,	FALSE },
@@ -77,10 +94,17 @@ struct configdef dkimf_config[] =
 #ifdef _FFR_REPLACE_RULES
 	{ "ReplaceRules",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_REPLACE_RULES */
+#ifdef _FFR_REPORT_INTERVALS
+	{ "ReportIntervalDB",		CONFIG_TYPE_STRING,	FALSE },
+#endif /* _FFR_REPORT_INTERVALS */
 	{ "ReportAddress",		CONFIG_TYPE_STRING,	FALSE },
-#ifdef _FFR_REQUIRED_HEADERS
+#ifdef _FFR_DKIM_REPUTATION
+	{ "ReputationFail",		CONFIG_TYPE_INTEGER,	FALSE },
+	{ "ReputationPass",		CONFIG_TYPE_INTEGER,	FALSE },
+	{ "ReputationReject",		CONFIG_TYPE_INTEGER,	FALSE },
+	{ "ReputationRoot",		CONFIG_TYPE_STRING,	FALSE },
+#endif /* _FFR_DKIM_REPUTATION */
 	{ "RequiredHeaders",		CONFIG_TYPE_BOOLEAN,	FALSE },
-#endif /* _FFR_REQUIRED_HEADERS */
 	{ "Selector",			CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_SELECTOR_HEADER
 	{ "SelectorHeader",		CONFIG_TYPE_STRING,	FALSE },
@@ -99,6 +123,11 @@ struct configdef dkimf_config[] =
 	{ "Syslog",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "SyslogFacility",		CONFIG_TYPE_STRING,	FALSE },
 	{ "SyslogSuccess",		CONFIG_TYPE_BOOLEAN,	FALSE },
+	{ "TemporaryDirectory",		CONFIG_TYPE_STRING,	FALSE },
+	{ "TestPublicKeys",		CONFIG_TYPE_STRING,	FALSE },
+#ifdef USE_UNBOUND
+	{ "TrustAnchorFile",		CONFIG_TYPE_STRING,	FALSE },
+#endif /* USE_UNBOUND */
 	{ "TrustSignaturesFrom",	CONFIG_TYPE_STRING,	FALSE },
 	{ "UMask",			CONFIG_TYPE_INTEGER,	FALSE },
 	{ "UserID",			CONFIG_TYPE_STRING,	FALSE },
