@@ -2,11 +2,11 @@
 **  Copyright (c) 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-crypto.c,v 1.1.2.2 2008/08/28 22:16:58 msk Exp $
+**  $Id: dkim-crypto.c,v 1.8 2008/11/10 23:55:41 ca Exp $
 */
 
 #ifndef lint
-static char dkim_crypto_c_id[] = "@(#)$Id: dkim-crypto.c,v 1.1.2.2 2008/08/28 22:16:58 msk Exp $";
+static char dkim_crypto_c_id[] = "@(#)$Id: dkim-crypto.c,v 1.8 2008/11/10 23:55:41 ca Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -18,6 +18,8 @@ static char dkim_crypto_c_id[] = "@(#)$Id: dkim-crypto.c,v 1.1.2.2 2008/08/28 22
 #include <openssl/crypto.h>
 #include <openssl/evp.h>
 #include <openssl/err.h>
+#include <openssl/ssl.h>
+#include <openssl/conf.h>
 
 /* libsm includes */
 #include <sm/gen.h>
@@ -47,7 +49,9 @@ static pthread_mutex_t *mutexes = NULL;
 */
 
 static void
-dkimf_crypto_lock_callback(int mode, int idx, const char *file, int line)
+dkimf_crypto_lock_callback(int mode, int idx,
+                           SM_UNUSED(const char *file),
+                           SM_UNUSED(int line))
 {
 	int status;
 
@@ -135,7 +139,8 @@ dkimf_crypto_free_id(void *ptr)
 */
 
 static struct CRYPTO_dynlock_value *
-dkimf_crypto_dyn_create(const char *file, int line)
+dkimf_crypto_dyn_create(SM_UNUSED(const char *file),
+                        SM_UNUSED(int line))
 {
 	int err;
 	pthread_mutex_t *new;
@@ -165,7 +170,8 @@ dkimf_crypto_dyn_create(const char *file, int line)
 
 static void
 dkimf_crypto_dyn_destroy(struct CRYPTO_dynlock_value *lock,
-                         const char *file, int line)
+                         SM_UNUSED(const char *file),
+                         SM_UNUSED(int line))
 {
 	assert(lock != NULL);
 
@@ -189,7 +195,8 @@ dkimf_crypto_dyn_destroy(struct CRYPTO_dynlock_value *lock,
 
 static void
 dkimf_crypto_dyn_lock(int mode, struct CRYPTO_dynlock_value *lock,
-                      const char *file, int line)
+                      SM_UNUSED(const char *file),
+                      SM_UNUSED(int line))
 {
 	int status;
 
@@ -253,6 +260,11 @@ dkimf_crypto_init(void)
 	CRYPTO_set_dynlock_lock_callback(&dkimf_crypto_dyn_lock);
 	CRYPTO_set_dynlock_destroy_callback(&dkimf_crypto_dyn_destroy);
 
+#if USE_OPENSSL_ENGINE
+	if (!SSL_set_engine(NULL))
+		return EINVAL;
+#endif /* USE_OPENSSL_ENGINE */
+
 	return 0;
 }
 
