@@ -2,14 +2,14 @@
 **  Copyright (c) 2008 Sendmail, Inc. and its suppliers.
 **      All rights reserved.
 **
-**  $Id: dkim-db.h,v 1.3 2008/02/28 21:04:41 msk Exp $
+**  $Id: dkim-db.h,v 1.4 2008/10/16 23:02:37 msk Exp $
 */
 
 #ifndef _DKIM_DB_H_
 #define _DKIM_DB_H_
 
 #ifndef lint
-static char dkim_db_h_id[] = "@(#)$Id: dkim-db.h,v 1.3 2008/02/28 21:04:41 msk Exp $";
+static char dkim_db_h_id[] = "@(#)$Id: dkim-db.h,v 1.4 2008/10/16 23:02:37 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -48,8 +48,12 @@ static char dkim_db_h_id[] = "@(#)$Id: dkim-db.h,v 1.3 2008/02/28 21:04:41 msk E
 #endif /* DB_VERSION_MAJOR < 2 */
 
 /* PROTOTYPES */
+extern int dkimf_db_delete __P((DB *, char *, pthread_mutex_t *));
+extern int dkimf_db_get __P((DB *, char *, void *, size_t *, bool *,
+                             pthread_mutex_t *));
 extern int dkimf_db_open_ro __P((DB **, const char *));
 extern int dkimf_db_open_rw __P((DB **, const char *));
-extern int dkimf_db_exists __P((DB *, char *, bool *, pthread_mutex_t *));
+extern int dkimf_db_put __P((DB *, char *, void *, size_t,
+                             pthread_mutex_t *));
 
 #endif /* _DKIM_DB_H_ */
