@@ -1,6 +1,6 @@
 #!/bin/sh
 ##
-## $Id: dkim-genkey.sh,v 1.3 2008/01/09 21:45:54 msk Exp $
+## $Id: dkim-genkey.sh,v 1.5 2008/03/27 21:14:12 msk Exp $
 ##
 ## Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 ## All rights reserved.
@@ -39,6 +39,7 @@ nosubdomains=0
 hashalgs=""
 keygran="*"
 note=""
+flags=""
 selector="default"
 restrict=0
 testmode=0
@@ -169,7 +170,6 @@ keydata=`grep -v '^-' ${selector}.public`
 pubkey=`echo $keydata | sed 's/ //g'`
 
 ## output the record
-flags=""
 if [ $testmode -eq 1 ]
 then
 	flags=" t=y"
@@ -183,21 +183,23 @@ then
 		flags=" t=s"
 	fi
 fi
+
+flagsout=""
 if [ "$flags" != "" ]
 then
-	flags=${flags}\;
+	flagsout="$flags;"
 fi
 
 hashout=""
 if [ "$hashalgs" != "" ]
 then
-	hashout=" h=$hashalgs\;"
+	hashout=" h=$hashalgs;"
 fi
 
 noteout=""
 if [ "$note" != "" ]
 then
-	noteout=" n=\"%s\"\;"
+	noteout=" n=\\\"$note\\\";"
 fi
 
 if [ "$domain" != "" ]
@@ -207,7 +209,7 @@ else
 	comment=""
 fi
 
-echo ${selector}._domainkey   IN   TXT  '"'v=DKIM1\;$noteout$hashalgs g=$keygran\; k=rsa\;$flags p=$pubkey'"' $comment > ${selector}.txt
+echo ${selector}._domainkey   IN   TXT  '"'v=DKIM1\;$noteout$hashout g=$keygran\; k=rsa\;$flagsout p=$pubkey'"' $comment > ${selector}.txt
 
 if [ $verbose -eq 1 ]
 then
