@@ -1,12 +1,12 @@
 /*
-**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: util.c,v 1.83 2008/12/15 19:59:38 msk Exp $
+**  $Id: util.c,v 1.87 2009/02/09 19:42:59 msk Exp $
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.83 2008/12/15 19:59:38 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.87 2009/02/09 19:42:59 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -1354,15 +1354,24 @@ dkimf_socket_cleanup(char *sockspec)
 	assert(sockspec != NULL);
 
 	/* we only care about "local" or "unix" sockets */
-	if (sockspec[0] != '/' &&
-	    strncasecmp(sockspec, "local:", 6) != 0 &&
-	    strncasecmp(sockspec, "unix:", 5) != 0)
-		return 0;
+	colon = strchr(sockspec, ':');
+	if (colon != NULL)
+	{
+		if (strncasecmp(sockspec, "local:", 6) != 0 &&
+		    strncasecmp(sockspec, "unix:", 5) != 0)
+			return 0;
+	}
 
 	/* find the filename */
-	colon = strchr(sockspec, ':');
-	if (colon == NULL || strlen(colon + 1) == 0)
-		return EINVAL;
+	if (colon == NULL)
+	{
+		colon = sockspec;
+	}
+	else
+	{
+		if (*(colon + 1) == '\0')
+			return EINVAL;
+	}
 
 	/* get a socket */
 	s = socket(PF_UNIX, SOCK_STREAM, 0);
@@ -1751,3 +1760,37 @@ dkimf_commaize(struct dkimf_dstring *dst, char *src, size_t ilen,
 	return acnt;
 }
 #endif /* _FFR_COMMAIZE */
+
+/*
+**  DKIMF_SUBDOMAIN -- determine whether or not one domain is a subdomain
+**                     of the other
+**
+**  Parameters:
+**  	d1 -- candidate domain
+**  	d2 -- possible superdomain
+**
+**  Return value:
+**  	TRUE iff d1 is a subdomain of d2.
+*/
+
+bool
+dkimf_subdomain(char *d1, char *d2)
+{
+	char *p;
+
+	assert(d1 != NULL);
+	assert(d2 != NULL);
+
+#if 0
+	if (strcasecmp(d1, d2) == 0)
+		return TRUE;
+#endif /* 0 */
+
+	for (p = strchr(d1, '.'); p != NULL; p = strchr(p + 1, '.'))
+	{
+		if (strcasecmp(d2, p + 1) == 0)
+			return TRUE;
+	}
+
+	return FALSE;
+}
