@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2004-2007 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2004-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char ar_c_id[] = "@(#)$Id: ar.c,v 1.72 2007/12/17 23:17:53 msk Exp $";
+static char ar_c_id[] = "@(#)$Id: ar.c,v 1.78 2009/02/14 09:08:12 msk Exp $";
 #endif /* !lint */
 
 /* OS stuff */
@@ -34,10 +34,16 @@ static char ar_c_id[] = "@(#)$Id: ar.c,v 1.72 2007/12/17 23:17:53 msk Exp $";
 #include <pthread.h>
 #include <assert.h>
 #include <signal.h>
+#include <string.h>
 
 /* libsm includes */
 #include <sm/gen.h>
-#include <sm/string.h>
+#ifdef WITHOUT_LIBSM
+# define sm_strlcat	strlcat
+# define sm_strlcpy	strlcpy
+#else /* WITHOUT_LIBSM */
+# include <sm/string.h>
+#endif /* WITHOUT_LIBSM */
 
 /* important macros */
 #ifndef MAXHOSTNAMELEN
@@ -128,6 +134,7 @@ struct ar_libhandle
 	struct ar_query *	ar_queriestail;	/* awaiting replies (tail) */
 	struct ar_query *	ar_recycle;	/* recyclable queries */
 	struct timeval		ar_retry;	/* retry interval */
+	struct __res_state	ar_res;		/* resolver data */
 };
 
 /*
@@ -148,12 +155,6 @@ static void *ar_malloc(AR_LIB, size_t);
 static void ar_free(AR_LIB lib, void *ptr);
 static int ar_res_init(AR_LIB);
 
-/*
-**  LIBRARY GLOBALS
-*/
-
-static struct __res_state ar_res;
-
 /*
 **  ========================= PRIVATE FUNCTIONS =========================
 */
@@ -667,9 +668,9 @@ ar_sendquery(AR_LIB lib, AR_QUERY query)
 		                query->q_type, NULL, 0, NULL, lib->ar_querybuf,
 		                lib->ar_querybuflen);
 #else /* defined(__RES) && (__RES <= 19960801) */
-		n = res_nmkquery(&ar_res, QUERY, query->q_name, query->q_class,
-		                query->q_type, NULL, 0, NULL, lib->ar_querybuf,
-		                lib->ar_querybuflen);
+		n = res_nmkquery(&lib->ar_res, QUERY, query->q_name,
+		                 query->q_class, query->q_type, NULL, 0,
+		                 NULL, lib->ar_querybuf, lib->ar_querybuflen);
 #endif /* defined(__RES) && (__RES <= 19960801) */
 
 		if (n != (size_t) -1)
@@ -775,6 +776,7 @@ static void *
 ar_dispatcher(void *tp)
 {
 	bool wrote;
+	bool usetimeout;
 	int status;
 	int maxfd;
 	AR_LIB lib;
@@ -816,8 +818,9 @@ ar_dispatcher(void *tp)
 		FD_SET(lib->ar_control[1], &rfds);
 
 		/* determine how long to wait */
-		timeout.tv_sec = INT_MAX;
+		timeout.tv_sec = AR_MAXTIMEOUT;
 		timeout.tv_usec = 0;
+		usetimeout = (lib->ar_queries != NULL);
 		for (q = lib->ar_queries; q != NULL; q = q->q_next)
 		{
 			/* check for absolute timeout */
@@ -846,7 +849,7 @@ ar_dispatcher(void *tp)
 
 		/* XXX -- effect a poll if we knew there was more pending */
 		status = select(maxfd + 1, &rfds, &wfds, NULL,
-		                lib->ar_queries != NULL ? &timeout : NULL);
+		                usetimeout ? &timeout : NULL);
 		if (status == -1)
 		{
 			if (errno == EINTR)
@@ -1222,7 +1225,7 @@ ar_res_init(AR_LIB new)
 
 	h_errno = NETDB_SUCCESS;
 
-	memset(&ar_res, '\0', sizeof ar_res);
+	memset(&new->ar_res, '\0', sizeof new->ar_res);
 
 	/*
 	**  We'll trust that res_init()/res_ninit() will give us things
@@ -1233,16 +1236,16 @@ ar_res_init(AR_LIB new)
 #if (defined(__RES) && (__RES <= 19960801))
 	/* old-school (bind4) */
 	res_init();
-	memcpy(&ar_res, &_res, sizeof ar_res);
+	memcpy(&new->ar_res, &_res, sizeof new->ar_res);
 #else /* defined(__RES) && (__RES <= 19960801) */
 	/* new-school (bind8 and up) */
-	(void) res_ninit(&ar_res);
+	(void) res_ninit(&new->ar_res);
 #endif /* defined(__RES) && (__RES <= 19960801) */
 
-	new->ar_nscount = ar_res.nscount;
-	new->ar_retry.tv_sec = ar_res.retrans;
+	new->ar_nscount = new->ar_res.nscount;
+	new->ar_retry.tv_sec = new->ar_res.retrans;
 	new->ar_retry.tv_usec = 0;
-	new->ar_retries = ar_res.retry;
+	new->ar_retries = new->ar_res.retry;
 
 	if (new->ar_nscount == 0)
 		new->ar_nscount = MAXNS;
@@ -1261,7 +1264,7 @@ ar_res_init(AR_LIB new)
 	if (new->ar_nsaddrs == NULL)
 		return -1;
 
-	memset(new->ar_nsaddrs, '\0', sizeof(SOCKADDR) * ar_res.nscount);
+	memset(new->ar_nsaddrs, '\0', sizeof(SOCKADDR) * new->ar_res.nscount);
 
 #if defined(AR_RES_MANUAL) || defined(AF_INET6)
 	ar_res_parse(&new->ar_nscount, new->ar_nsaddrs,
@@ -1601,6 +1604,17 @@ ar_addquery(AR_LIB lib, char *name, int class, int type, int depth,
 		prev = *p;
 	}
 
+	/* sanity-check the timeout, if provided */
+	if (timeout != NULL)
+	{
+		if (timeout->tv_sec < 0 || timeout->tv_sec > AR_MAXTIMEOUT ||
+		    timeout->tv_usec < 0 || timeout->tv_usec >= 1000000)
+		{
+			errno = EINVAL;
+			return NULL;
+		}
+	}
+
 	pthread_mutex_lock(&lib->ar_lock);
 
 	if ((lib->ar_flags & AR_FLAG_DEAD) != 0)
