@@ -1,12 +1,12 @@
 /*
-**  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2007-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifdef QUERY_CACHE
 
 #ifndef lint
-static char dkim_cache_c_id[] = "@(#)$Id: dkim-cache.c,v 1.27 2008/07/22 20:42:38 msk Exp $";
+static char dkim_cache_c_id[] = "@(#)$Id: dkim-cache.c,v 1.29 2009/02/07 01:01:33 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -23,7 +23,12 @@ static char dkim_cache_c_id[] = "@(#)$Id: dkim-cache.c,v 1.27 2008/07/22 20:42:3
 #include <sm/gen.h>
 #include <sm/types.h>
 #include <sm/cdefs.h>
-#include <sm/string.h>
+#ifdef WITHOUT_LIBSM
+# define sm_strlcat	strlcat
+# define sm_strlcpy	strlcpy
+#else /* WITHOUT_LIBSM */
+# include <sm/string.h>
+#endif /* WITHOUT_LIBSM */
 
 /* libdb includes */
 #include <db.h>
