@@ -6,10 +6,10 @@
 #ifndef _DKIM_CACHE_H_
 #define _DKIM_CACHE_H_
 
-#ifdef _FFR_QUERY_CACHE
+#ifdef QUERY_CACHE
 
 #ifndef lint
-static char dkim_cache_h_id[] = "@(#)$Id: dkim-cache.h,v 1.3 2007/09/18 22:12:38 msk Exp $";
+static char dkim_cache_h_id[] = "@(#)$Id: dkim-cache.h,v 1.4 2007/10/24 06:25:57 msk Exp $";
 #endif /* !lint */
 
 /* libdb includes */
@@ -23,6 +23,6 @@ extern int dkim_cache_insert __P((DB *, char *, char *, int, int *));
 extern int dkim_cache_query __P((DB *, char *, int, char *, size_t *, int *));
 extern void dkim_cache_stats __P((u_int *, u_int *, u_int *));
 
-#endif /* _FFR_QUERY_CACHE */
+#endif /* QUERY_CACHE */
 
 #endif /* ! _DKIM_CACHE_H_ */
