@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2007-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.51 2008/11/26 01:20:28 msk Exp $";
+static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.53 2009/02/07 01:01:33 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -20,7 +20,12 @@ static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.51 2008/11/26 01:20:2
 #include <sm/gen.h>
 #include <sm/types.h>
 #include <sm/cdefs.h>
-#include <sm/string.h>
+#ifdef WITHOUT_LIBSM
+# define sm_strlcat	strlcat
+# define sm_strlcpy	strlcpy
+#else /* WITHOUT_LIBSM */
+# include <sm/string.h>
+#endif /* WITHOUT_LIBSM */
 
 /* libdkim includes */
 #include "dkim.h"
