@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.43 2008/12/05 22:03:02 msk Exp $";
+static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.45 2009/02/07 01:01:33 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -25,7 +25,12 @@ static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.43 2008/12/05 22:03:02
 #include <sm/gen.h>
 #include <sm/types.h>
 #include <sm/cdefs.h>
-#include <sm/string.h>
+#ifdef WITHOUT_LIBSM
+# define sm_strlcat	strlcat
+# define sm_strlcpy	strlcpy
+#else /* WITHOUT_LIBSM */
+# include <sm/string.h>
+#endif /* WITHOUT_LIBSM */
 
 /* libar includes */
 #if USE_ARLIB
