@@ -7,7 +7,7 @@
 #define _DKIM_TABLES_H_
 
 #ifndef lint
-static char dkim_tables_h_id[] = "@(#)$Id: dkim-tables.h,v 1.16 2008/02/29 00:37:22 msk Exp $";
+static char dkim_tables_h_id[] = "@(#)$Id: dkim-tables.h,v 1.17 2008/04/08 23:35:56 msk Exp $";
 #endif /* !lint */
 
 /* structures */
@@ -17,20 +17,15 @@ struct nametable
 	const int	tbl_code;	/* code */
 };
 
-struct chartable
-{
-	const int	tbl_char;	/* character */
-	const int	tbl_code;	/* code */
-};
-
 /* tables */
-struct chartable *keyparams;
-
 struct nametable *algorithms;
 struct nametable *canonicalizations;
 struct nametable *hashes;
+struct nametable *keyflags;
+struct nametable *keyparams;
 struct nametable *keytypes;
 struct nametable *policies;
+struct nametable *policyflags;
 struct nametable *policyparams;
 struct nametable *policyresults;
 struct nametable *querytypes;
@@ -38,8 +33,6 @@ struct nametable *results;
 struct nametable *settypes;
 struct nametable *sigerrors;
 struct nametable *sigparams;
-struct nametable *policyflags;
-struct nametable *keyflags;
 
 /* prototypes */
 extern const char *dkim_code_to_name __P((struct nametable *tbl,
@@ -47,9 +40,4 @@ extern const char *dkim_code_to_name __P((struct nametable *tbl,
 extern const int dkim_name_to_code __P((struct nametable *tbl,
                                         const char *name));
 
-extern const int dkim_code_to_char __P((struct chartable *tbl,
-                                        const int code));
-extern const int dkim_char_to_code __P((struct chartable *tbl,
-                                        const int code));
-
 #endif /* _DKIM_TABLES_H_ */
