@@ -7,15 +7,15 @@
 #define _DKIM_TEST_H_
 
 #ifndef lint
-static char dkim_test_h_id[] = "@(#)$Id: dkim-test.h,v 1.7 2008/05/13 19:56:54 msk Exp $";
+static char dkim_test_h_id[] = "@(#)$Id: dkim-test.h,v 1.9 2008/07/10 18:10:12 msk Exp $";
 #endif /* !lint */
 
 /* libdkim includes */
 #include "dkim.h"
 
 /* prototypes */
-extern int dkim_test_asp __P((DKIM_LIB *, char *, dkim_policy_t *,
-                              int *, char *, size_t));
+extern int dkim_test_adsp __P((DKIM_LIB *, const char *, dkim_policy_t *,
+                               int *, char *, size_t));
 extern int dkim_test_key __P((DKIM_LIB *, char *, char *, char *, size_t,
                               char *, size_t));
 
