@@ -7,7 +7,7 @@
 #define _DKIM_TYPES_H_
 
 #ifndef lint
-static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.90 2008/07/10 17:28:37 msk Exp $";
+static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.91 2008/10/31 03:06:04 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -36,6 +36,11 @@ static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.90 2008/07/10 17:28:3
 # include <db.h>
 #endif /* QUERY_CACHE */
 
+#ifdef USE_UNBOUND
+/* libunbound includes */
+# include <unbound.h>
+#endif /* USE_UNBOUND */
+
 /* libdkim includes */
 #include "dkim.h"
 
@@ -101,6 +106,9 @@ struct dkim_siginfo
 	u_int			sig_hashtype;
 	u_int			sig_keytype;
 	u_int			sig_keybits;
+#ifdef USE_UNBOUND
+	u_int			sig_dnssec_key;
+#endif /* USE_UNBOUND */
 	size_t			sig_siglen;
 	size_t			sig_keylen;
 	size_t			sig_b64keylen;
@@ -188,6 +196,20 @@ struct dkim_test_dns_data
 	struct dkim_test_dns_data * dns_next;
 };
 
+/* struct dkim_unbound_cb_data -- libunbound callback data */
+struct dkim_unbound_cb_data
+{
+	int			ubd_done;
+	int			ubd_rcode;
+	int			ubd_id;
+	int			ubd_type;
+	u_int			ubd_result;
+	DKIM_STAT		ubd_stat;
+	size_t			ubd_buflen;
+	u_char *		ubd_buf;
+	const char *		ubd_jobid;
+};
+
 /* struct dkim -- a complete DKIM transaction context */
 struct dkim
 {
@@ -208,6 +230,9 @@ struct dkim
 #endif /* QUERY_CACHE */
 	u_int			dkim_version;
 	u_int			dkim_sigcount;
+#ifdef USE_UNBOUND
+	u_int			dkim_dnssec_policy;
+#endif /* USE_UNBOUND */
 	size_t			dkim_margin;
 	size_t			dkim_b64siglen;
 	size_t			dkim_keylen;
@@ -260,6 +285,9 @@ struct dkim_lib
 {
 	bool			dkiml_signre;
 	bool			dkiml_skipre;
+#ifdef USE_UNBOUND
+	bool			dkiml_ub_poller;
+#endif /* USE_UNBOUND */
 	u_int			dkiml_flags;
 	u_int			dkiml_timeout;
 	u_int			dkiml_version;
@@ -284,6 +312,11 @@ struct dkim_lib
 #endif /* QUERY_CACHE */
 	regex_t			dkiml_hdrre;
 	regex_t			dkiml_skiphdrre;
+#ifdef USE_UNBOUND
+	struct ub_ctx *		dkiml_unbound_ctx;
+	pthread_mutex_t		dkiml_ub_lock;
+	pthread_cond_t		dkiml_ub_ready;
+#endif /* USE_UNBOUND */
 	DKIM_CBSTAT		(*dkiml_key_lookup) (DKIM *dkim,
 				                     DKIM_SIGINFO *sig,
 				                     u_char *buf,
