@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_signperf_c_id[] = "@(#)$Id: t-signperf.c,v 1.5 2008/06/05 15:23:18 msk Exp $";
+static char t_signperf_c_id[] = "@(#)$Id: t-signperf.c,v 1.6 2008/07/22 20:51:17 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -16,6 +16,9 @@ static char t_signperf_c_id[] = "@(#)$Id: t-signperf.c,v 1.5 2008/06/05 15:23:18
 #include <unistd.h>
 #include <sysexits.h>
 
+/* libsm includes */
+#include <sm/gen.h>
+
 /* libdkim includes */
 #include "dkim.h"
 #include "dkim-tables.h"
