@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test111_c_id[] = "@(#)$Id: t-test111.c,v 1.2 2008/05/10 20:17:42 msk Exp $";
+static char t_test111_c_id[] = "@(#)$Id: t-test111.c,v 1.3 2008/07/22 20:51:17 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -13,6 +13,9 @@ static char t_test111_c_id[] = "@(#)$Id: t-test111.c,v 1.2 2008/05/10 20:17:42 m
 #include <string.h>
 #include <stdio.h>
 
+/* libsm includes */
+#include <sm/gen.h>
+
 /* libdkim includes */
 #include "dkim.h"
 #include "util.h"
