@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test120_c_id[] = "@(#)$Id: t-test120.c,v 1.4 2008/07/22 20:51:17 msk Exp $";
+static char t_test120_c_id[] = "@(#)$Id: t-test120.c,v 1.5 2008/10/07 20:47:55 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -53,10 +53,12 @@ main(int argc, char **argv)
 	lib = dkim_init(NULL, NULL);
 	assert(lib != NULL);
 
+#ifdef TEST_KEEP_FILES
 	/* set flags */
 	flags = (DKIM_LIBFLAGS_TMPFILES|DKIM_LIBFLAGS_KEEPFILES);
 	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_FLAGS, &flags,
 	                    sizeof flags);
+#endif /* TEST_KEEP_FILES */
 
 	key = KEY;
 
