@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test49_c_id[] = "@(#)$Id: t-test49.c,v 1.11 2008/04/25 16:36:27 msk Exp $";
+static char t_test49_c_id[] = "@(#)$Id: t-test49.c,v 1.12 2008/07/22 20:51:17 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -19,6 +19,9 @@ static char t_test49_c_id[] = "@(#)$Id: t-test49.c,v 1.11 2008/04/25 16:36:27 ms
 # include <db.h>
 #endif /* QUERY_CACHE */
 
+/* libsm includes */
+#include <sm/gen.h>
+
 /* libdkim includes */
 #include "dkim.h"
 #include "dkim-cache.h"
