@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test73_c_id[] = "@(#)$Id: t-test73.c,v 1.9 2008/07/22 20:51:17 msk Exp $";
+static char t_test73_c_id[] = "@(#)$Id: t-test73.c,v 1.11 2008/10/16 22:51:47 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -56,6 +56,7 @@ main(int argc, char **argv)
 	unsigned char addr[MAXADDRESS + 1];
 	unsigned char fmt[BUFRSZ];
 	unsigned char opts[BUFRSZ];
+	unsigned char smtp[BUFRSZ];
 
 	printf("*** simple/simple rsa-sha256 verifying with extra signature spaces and reportinfo (failure)\n");
 
@@ -172,14 +173,17 @@ main(int argc, char **argv)
 	memset(addr, '\0', sizeof addr);
 	memset(fmt, '\0', sizeof fmt);
 	memset(opts, '\0', sizeof opts);
+	memset(smtp, '\0', sizeof smtp);
 	status = dkim_sig_getreportinfo(dkim, sig, &hfd, &bfd,
 	                                addr, sizeof addr,
 	                                fmt, sizeof fmt,
-	                                opts, sizeof opts);
+	                                opts, sizeof opts,
+	                                smtp, sizeof smtp, NULL);
 	assert(status == DKIM_STAT_OK);
 	assert(hfd > 2);
 	assert(bfd > 2);
 	assert(strcmp(addr, REPLYADDRESS) == 0);
+	assert(strcmp(smtp, SMTPTOKEN) == 0);
 
 	/* test descriptors */
 	status = lseek(hfd, 0, SEEK_CUR);
