@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test98_c_id[] = "@(#)$Id: t-test98.c,v 1.2 2008/04/25 16:37:04 msk Exp $";
+static char t_test98_c_id[] = "@(#)$Id: t-test98.c,v 1.3 2008/07/22 20:51:17 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -13,6 +13,9 @@ static char t_test98_c_id[] = "@(#)$Id: t-test98.c,v 1.2 2008/04/25 16:37:04 msk
 #include <string.h>
 #include <stdio.h>
 
+/* libsm includes */
+#include <sm/gen.h>
+
 /* libdkim includes */
 #include "dkim.h"
 #include "t-testdata.h"
