@@ -4,13 +4,14 @@
 */
 
 #ifndef lint
-static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.17 2008/05/22 06:27:24 msk Exp $";
+static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.20 2008/09/06 20:31:37 msk Exp $";
 #endif /* !lint */
 
 
 #define	CRLF		"\r\n"
 
 #define	LARGEBODYSIZE	65536
+#define	LARGELINESIZE	4100
 
 #define	KEYFILE		"/var/tmp/testkeys"
 
@@ -28,6 +29,8 @@ static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.17 2008/05/22 06:27:24 m
 #define	DOMAIN		"example.com"
 #define	DOMAIN2		"sendmail.com"
 #define	REPLYADDRESS	"postmaster"
+#define	SMTPTOKENENC	"=5BDKIM=20error=5D"
+#define	SMTPTOKEN	"[DKIM error]"
 
 #define	HEADER01	"Received: received data 0"
 #define	HEADER02	"Received: received data 1"
@@ -98,7 +101,8 @@ static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.17 2008/05/22 06:27:24 m
 	"IW2oWFfZCB4APkIis79Ql45AHpavwx5XodBMzZwJUvlL\n" \
 	"-----END RSA PRIVATE KEY-----\n"
 #define	PUBLICKEY	"v=DKIM1; k=rsa; t=y:s; h=sha1:sha256; " \
-	"r=" REPLYADDRESS "; p=" \
+	"r=" REPLYADDRESS "; " \
+	"rs=" SMTPTOKENENC "; p=" \
 	"MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQC4GUGr+d/6SFNzVLYpphnRd0QP" \
 	"GKz2uWnV65RAxa1Pw352BqizqiKOBjgYGzj8pJQSs8tOvv/2k6jpI809RnESqOFg" \
 	"F0gu3UJbNnu3+cd8k/kiQj+q4cKKRpAT92ccxc7svhCNgN1sBGmROYZuysG3Vu3D" \
