@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.26 2008/10/31 03:06:05 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.28 2009/02/07 01:01:33 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -21,7 +21,14 @@ static char util_c_id[] = "@(#)$Id: util.c,v 1.26 2008/10/31 03:06:05 msk Exp $"
 #include <stdlib.h>
 
 /* libsm includes */
-#include <sm/string.h>
+#include <sm/gen.h>
+#ifdef WITHOUT_LIBSM
+# define sm_strlcat	strlcat
+# define sm_strlcpy	strlcpy
+#else /* WITHOUT_LIBSM */
+/* libsm includes */
+# include <sm/string.h>
+#endif /* WITHOUT_LIBSM */
 
 /* libdkim includes */
 #include "dkim.h"
