@@ -7,11 +7,15 @@
 #define _UTIL_H_
 
 #ifndef lint
-static char util_h_id[] = "@(#)$Id: util.h,v 1.17 2008/05/08 00:19:33 msk Exp $";
+static char util_h_id[] = "@(#)$Id: util.h,v 1.19 2008/10/31 04:13:04 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
 #include <sys/types.h>
+#include <sys/time.h>
+#ifdef USE_UNBOUND
+# include <sys/select.h>
+#endif /* USE_UNBOUND */
 
 /* libsm includes */
 #include <sm/gen.h>
@@ -27,6 +31,10 @@ extern bool dkim_hdrlist __P((u_char *, size_t, u_char **, bool));
 extern int dkim_hexchar __P((int c));
 extern void dkim_lowerhdr __P((u_char *));
 extern int dkim_qp_decode __P((u_char *, u_char *, int));
+#ifdef USE_UNBOUND
+extern bool dkim_timespec_past __P((struct timespec *tv));
+extern int dkim_wait_fd __P((int fd, struct timespec *until));
+#endif /* USE_UNBOUND */
 
 #ifdef NEED_FAST_STRTOUL
 extern unsigned long dkim_strtoul __P((const char *str, char **endptr,
