@@ -7,7 +7,7 @@
 #define _VBR_H_
 
 #ifndef lint
-static char vbr_h_id[] = "@(#)$Id: vbr.h,v 1.9 2007/09/07 00:28:57 msk Exp $";
+static char vbr_h_id[] = "@(#)$Id: vbr.h,v 1.11 2007/10/30 19:39:20 msk Exp $";
 #endif /* !lint */
 
 /* strings */
@@ -208,6 +208,21 @@ extern void vbr_setcallbackint __P((VBR *, u_int));
 */
 
 extern void vbr_setcallbackctx __P((VBR *, void *));
+
+/*
+**  VBR_SETDNSCALLBACK -- set the DNS wait callback
+**
+**  Parameters:
+**  	vbr -- VBR handle, created by vbr_init()
+**  	func -- function to call; should take an opaque context pointer
+**
+**  Return value:
+**  	None.
+*/
+
+extern VBR_STAT vbr_setdnscallback __P((VBR *vbr,
+                                        void (*func)(const void *context)));
+
 #endif /* USE_ARLIB */
 
 #endif /* _VBR_H_ */
